@@ -390,11 +390,11 @@ class Mirror(object):
         return '<a href="%s/">%s</a>' % (filename, filename)
 
     def _index_html(self):
-        header = "<html><body><h1>PyPi Mirror</h1><h2>Last update: " + \
+        header = "<html><body><h1>PyPI Mirror</h1><h2>Last update: " + \
                  time.strftime("%c %Z")+"</h2>\n"
         _ls = self.ls()
         links = "<br />\n".join([self._html_link(link) for link in _ls])
-        generator = "<p class='footer'>Generated by %s; %d packages mirrored.</p>" % (pypimirror_version(), len(_ls))
+        generator = "<p class='footer'>Generated by %s; %d packages mirrored. For details see the <a href='http://www.openplans.org/projects/pypi-mirroring'>pypi mirroring z3c.pypimirror project page.</a></p>" % (pypimirror_version(), len(_ls))
         footer = "</body></html>\n"
         return "\n".join((header, links, generator, footer))
 
